@@ -1,4 +1,4 @@
-#' Plot a 3-D (using RGL) view of a model, including design points
+#' @title Plot a 3-D (using RGL) view of a model, including design points
 #' @description Plot a 3-D view of a model, thus providing a better understanding of its behaviour.
 #' @param model a list that can be used in the \code{modelPredict} function of the \pkg{DiceEval} package.
 #' @param center optional coordinates (as a list or data frame) of the center of the section view if the model's dimension is > 2.
@@ -16,6 +16,7 @@
 #' @param yscale an optional factor to scale y.
 #' @param title an optional overload of main title.
 #' @param add to print graphics on an existing window.
+#' @param engine3d 3D view package to use. "rgl" if available, otherwise "scatterplot3d" by default.
 #' @param ... optional arguments passed to the first call of \code{plot3d}.
 #' @importFrom DiceEval modelPredict
 #' @importFrom DiceKriging branin
@@ -26,7 +27,6 @@
 # @importFrom rgl open3d
 #' @method sectionview3d list
 #' @docType methods
-#' @rdname list-methods
 #' @export
 #' @details Experimental points are plotted with fading colors. Points that fall in the specified section (if any) have the color specified \code{col_points} while points far away from the center have shaded versions of the same color. The amount of fading is determined using the Euclidean distance between the plotted point and \code{center}. The variables chosen with their number are to be found in the \code{data$X} element of the model. Thus they are original data variables but not trend variables that may have been created using the model's formula
 #' @author Yann Richet, IRSN
@@ -44,7 +44,9 @@
 #' m1 <- modelFit(design.fact, y[[1]], type = "Linear", formula = "Y~.")
 #'
 #' ## the same as sectionview3d.list
-#' sectionview3d(m1)
+#' if (identical(Sys.getenv("NOT_CRAN"), "true")) { # too long for CRAN on Windows
+#'   sectionview3d(m1)
+#' }
 sectionview3d.list <- function(model,
 		center = NULL, axis = NULL,
 		npoints = 20,
@@ -57,8 +59,9 @@ sectionview3d.list <- function(model,
         xlim = NULL, ylim = NULL,
         title = NULL,
         add = FALSE,
+		engine3d = NULL,
         ...) {
-    if (is.null(load3d())) return()
+    if (is.null(load3d(engine3d))) return()
 
     D <- length(model$data$X)
     if (D == 1) stop("for a model with dim 1, use 'sectionview'")
